<?php

define('FLICKR_API_KEY', 'REPLACE_WITH_YOUR_API_KEY');
define('PATH_TO_CACHE', 'cache'); // path to cache WITHOUT trailing slash (can be relative)
define('URL_TO_CACHE', 'cache'); // url to cache WITHOUT trailing slash (can be relative)

//---------------------------------------------
//load stack default settings from file
//---------------------------------------------
    
if (file_exists('stack/3dstack.xml'))
{
    $xml = simplexml_load_file('stack/3dstack.xml');
}
else
{
    die('settings file is missing');
}

//---------------------------------------------
// flickr request
//---------------------------------------------

function send_request($params)
{
  // build the API URL to call
  $params = $params + array(
    'api_key'	=> FLICKR_API_KEY,
    'format'	=> 'php_serial'
  );

  $encoded_params = array();

  foreach ($params as $k => $v)
  {
    $encoded_params[] = urlencode($k).'='.urlencode($v);
  }

  $request = "http://api.flickr.com/services/rest/?".implode('&', $encoded_params);
  
  //---------------------------------------------
  // use cURL to send the request
  //---------------------------------------------
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $request);
  curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, CURLOPT_HEADER, 0);
  $response = curl_exec($ch);
  curl_close($ch);

  return unserialize($response);
}

// END send_request function

// get interesting photos
$rsp_obj = send_request(array('method' => 'flickr.interestingness.getList', 'per_page' => 30));

if ($rsp_obj['stat'] != 'ok')
{
  $error_msg = (isset($rsp_obj['message'])) ? $rsp_obj['message'] : 'Unknown error.';
  die($error_msg);
}

//---------------------------------------------
// parse items
//---------------------------------------------

// create an empty array
$images = array();

for ($i = 0; $i < count($rsp_obj['photos']['photo']); $i++)
{
  $file = $rsp_obj['photos']['photo'][$i];

  // http://farm{farm-id}.static.flickr.com/{server-id}/{id}_{secret}_s.jpg
  $img_url = 'http://farm'.$file['farm'].'.static.flickr.com/'.$file['server'].'/'.$file['id'].'_'.$file['secret'].'_s.jpg'; 
  $img_md5 = md5($img_url);
      
  // we will cache the image on the server
  if (!file_exists(PATH_TO_CACHE.'/'.$img_md5.'.jpg'))
  {
    // store the image on the server (we will use the md5 hash as filename)
    $fp = fopen(PATH_TO_CACHE.'/'.$img_md5.'.jpg', 'w');
    
    // use cURL to get the image
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $img_url);
    curl_setopt($ch, CURLOPT_FILE, $fp);
    curl_exec($ch);
    curl_close($ch);

    fclose($fp);
    
    // resize
    $new_img = imagecreatefromjpeg(PATH_TO_CACHE.'/'.$img_md5.'.jpg');
    $resized_img = imagecreatetruecolor(150,150);   
    imagecopyresized($resized_img, $new_img, 0, 0, 0, 0, 150, 150, 75, 75);
    imagejpeg($resized_img,PATH_TO_CACHE.'/'.$img_md5.'.jpg');
	imagedestroy($resized_img);
	imagedestroy($new_img);
  }
      
  // create new item
  $item = array (
    'ImagePath' 	  =>  URL_TO_CACHE.'/'.$img_md5.'.jpg',   
    'ImageLink'		  =>  'http://www.flickr.com/photos/'.$file['owner'].'/'.$file['id'], // // http://www.flickr.com/photos/{user-id}/{photo-id}
    'ImageLinkTarget' =>  '_blank',
    'ToolTip'         =>  $file['title'],
    'Content1'		  =>  '',
    'Content2'		  =>  '',
    'JSFunction'      =>  ''
  );
  
  // add the item to the array
  array_push($images, $item);
}

//---------------------------------------------
// add entries to generated config file
//---------------------------------------------

foreach ($images as $entry)
{
	$tag = $xml->Images->addChild('Image');
	foreach ($entry as $key => $value)
	{
		$tag->addChild($key, '<![CDATA['.htmlentities($value).']]>');
	}
}

print_r(html_entity_decode($xml->asXML()));

?>